#
# spec file
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2018 Matthias Fehring <buschmann23@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define _pkgname celery-batches
Name:           python-%{_pkgname}
Version:        0.8.1
Release:        1.3
Summary:        Django module to process multiple Celery task requests together
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/percipient/celery-batches
Source:         https://github.com/percipient/%{_pkgname}/archive/v%{version}.tar.gz#/%{_pkgname}-%{version}.tar.gz
Patch0:         celery-fixtures.patch
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module celery >= 5.0}
BuildRequires:  %{python_module coverage}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module pytz}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-celery >= 4.4
BuildArch:      noarch
%python_subpackages

%description
An alternate way to have Django DRY forms. The developer can build
programmatic reusable layouts out of components, having control of
the rendered HTML without writing HTML in templates, without breaking
the standard way of doing things in Django, so that it still works
with any other form application.

%prep
%autosetup -p1 -n %{_pkgname}-%{version}

%build
%pyproject_wheel

%install
%pyproject_install

%check
%pytest t/

%files %{python_files}
%doc README.rst CHANGELOG.rst
%license LICENSE
%{python_sitelib}/*

%changelog
* Wed Aug  9 2023 Dirk Müller <dmueller@suse.com>
- update to 0.8.1:
  * Fix installing celery-batches with Celery 5.3.
  * Support passing through the `request_dict` from the original
    Celery request.
  * Support Celery 5.3.
  * Drop support for Celery < 5.0.
  * Support Python 3.11.
  * Drop support for Python 3.7.
* Thu Mar 30 2023 Dirk Müller <dmueller@suse.com>
- update to 0.7:
  * Support passing multiple or keyword arguments by disabling
    Celery's ``typing``  feature for ``Batches`` tasks.
  * Support |using a custom Request class|_ for ``Batches``
    tasks.
  * Support calling tasks with an ``eta`` or ``countdown``
    specified.
  * Handle "hybrid" messages that have moved between Celery
    versions.
  * Fix task ETA issues when timezone is defined in
    configuration.
  * Simplify tests.
  * Improve PyPI metadata.
  * Update README badges to include PyPI and GitHub Actions
  * Update copyright information.
  * Document use-cases and include more examples.
  * Run the unit tests against RabbitMQ & Redis brokers/backends.
  * Run `black <https://black.readthedocs.io/>`_, `isort
    <https://pycqa.github.io/isort/>`_,
  * `flake8 <https://flake8.pycqa.org>`_, `pyupgrade
    <https://github.com/asottile/pyupgrade>`_,
  * Fix a bug when passing a ``request`` to ``mark_as_done`` with
    Celery 5.1.0.
  * Clean-up and re-organize code.
  * Support Celery 5.2.
  * Drop support for Python 3.6.
  * Support Python 3.10.
* Tue Jan 26 2021 Markéta Machová <mmachova@suse.com>
- Update to 0.4
  * Officially support Celery 5.0. Drop support for Celery < 4.4.
  * Drop support for Python < 3.6.
- Add celery-fixtures.patch to fix the testsuite
* Mon Mar 30 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to version 0.3
  * Properly set the ``current_task`` when running Batch tasks.
  * Call the success signal after a successful run of the Batch task.
  * Support running tasks eagerly via the ``Task.apply()`` method. This causes
    the task to execute with a batch of a single item.
  * Officially support Python 3.7 and 3.8. Drop support for Python 3.4.
  * Officially support Celery 4.3 and 4.4.
* Thu Dec  5 2019 John Vandenberg <jayvdb@gmail.com>
- Remove test suite from runtime package
* Sun Jan 13 2019 Jan Engelhardt <jengelh@inai.de>
- Trim bias and use noun phrasing.
* Wed Jan  2 2019 Tomáš Chvátal <tchvatal@suse.com>
- Really run tests
- Sort out with spec-cleaner
* Fri Nov 30 2018 Matthias Fehring <buschmann23@opensuse.org>
- Initial package version 0.2
